## A simple tool to remove blobs from 2D/3D point cloud data as produced by MINFLUX

### Please, find the Data used in the work in `Example_Data`, the source code in `blobBgone` and all Figures appearaing in the main text in `Figures`.

Dependencies:
- Python 3
- Numpy
- Scipy
- Matplotlib
- Scikit-learn
- seaborn
- Pandas (Only for Evaluation)
- TkInter (If on Windows)

More precise dependencies will come once the original article is published.
Technically, this should run on both Windows and Linux. 